@@ -224,7 +224,7 @@ apprise_url_tests = (
         "barks://192.168.0.7/device_key/",
         {
             "instance": NotifyBark,
-            # throw a bizzare code forcing us to fail to look it up
+            # throw a bizarre code forcing us to fail to look it up
             "response": False,
             "requests_response_code": 999,
             # Our expected url(privacy=True) startswith() response:
@@ -236,7 +236,7 @@ apprise_url_tests = (
         {
             "instance": NotifyBark,
             # Throws a series of i/o exceptions with this flag
-            # is set and tests that we gracfully handle them
+            # is set and tests that we gracefully handle them
             "test_requests_exceptions": True,
         },
     ),
@@ -254,6 +254,20 @@ apprise_url_tests = (
             "instance": NotifyBark,
         },
     ),
+    (
+        "bark://192.168.0.6:8081/device_key/?call=1",
+        {
+            # set call parameter to repeat ringtone
+            "instance": NotifyBark,
+        },
+    ),
+    (
+        "bark://192.168.0.6:8081/device_key/?call=1&sound=alarm&level=critical",
+        {
+            # set call parameter with other parameters
+            "instance": NotifyBark,
+        },
+    ),
 )
 
 
